Merge 'develop' into 'amd-staging'

Change-Id: I46d0c7fbf31139e36587c65cac05a33e0bf252c2
This commit is contained in:
Jenkins
2023-03-02 00:11:10 +00:00
bovenliggende 494e8b80bb d6f2962c78
commit dc4fb5565c
4 gewijzigde bestanden met toevoegingen van 34 en 17 verwijderingen
@@ -106,6 +106,7 @@ TEST_CASE("Unit_hipEventElapsedTime_NotReady_Negative") {
HIP_CHECK_ERROR(hipEventQuery(stop), hipErrorNotReady);
HIP_ASSERT(hipEventElapsedTime(&tElapsed,start,stop) == hipErrorNotReady);
HIP_CHECK(hipStreamSynchronize(nullptr));
HIP_CHECK(hipEventDestroy(start));
HIP_CHECK(hipEventDestroy(stop));
}
+10 -4
Bestand weergeven
@@ -138,13 +138,19 @@ TEST_CASE("Unit_hipMemcpyPeer_Positive_ZeroSize") {
const auto element_count = allocation_size / sizeof(*src_alloc.ptr());
constexpr auto thread_count = 1024;
const auto block_count = element_count / thread_count + 1;
constexpr int set_value = 22;
constexpr int set_value_s = 22;
HIP_CHECK(hipSetDevice(src_device));
VectorSet<<<block_count, thread_count, 0>>>(src_alloc.ptr(), set_value, element_count);
VectorSet<<<block_count, thread_count, 0>>>(src_alloc.ptr(), set_value_s, element_count);
HIP_CHECK(hipGetLastError());
constexpr int expected_value = 21;
std::fill_n(src_alloc.host_ptr(), element_count, expected_value);
constexpr int expected_value = 20;
HIP_CHECK(hipSetDevice(dst_device));
VectorSet<<<block_count, thread_count, 0>>>(dst_alloc.ptr(), expected_value, element_count);
HIP_CHECK(hipGetLastError());
HIP_CHECK(hipSetDevice(src_device));
constexpr int set_value_h = 21;
std::fill_n(result.host_ptr(), element_count, set_value_h);
HIP_CHECK(hipMemcpyPeer(dst_alloc.ptr(), dst_device, src_alloc.ptr(), src_device, 0));
@@ -154,13 +154,19 @@ TEST_CASE("Unit_hipMemcpyPeerAsync_Positive_ZeroSize") {
const auto element_count = allocation_size / sizeof(*src_alloc.ptr());
constexpr auto thread_count = 1024;
const auto block_count = element_count / thread_count + 1;
constexpr int set_value = 22;
constexpr int set_value_s = 22;
HIP_CHECK(hipSetDevice(src_device));
VectorSet<<<block_count, thread_count, 0, stream>>>(src_alloc.ptr(), set_value, element_count);
VectorSet<<<block_count, thread_count, 0, stream>>>(src_alloc.ptr(), set_value_s, element_count);
HIP_CHECK(hipGetLastError());
constexpr int expected_value = 21;
std::fill_n(src_alloc.host_ptr(), element_count, expected_value);
constexpr int expected_value = 20;
HIP_CHECK(hipSetDevice(dst_device));
VectorSet<<<block_count, thread_count, 0, stream>>>(dst_alloc.ptr(), expected_value, element_count);
HIP_CHECK(hipGetLastError());
HIP_CHECK(hipSetDevice(src_device));
constexpr int set_value_h = 21;
std::fill_n(result.host_ptr(), element_count, set_value_h);
HIP_CHECK(
hipMemcpyPeerAsync(dst_alloc.ptr(), dst_device, src_alloc.ptr(), src_device, 0, stream));
@@ -189,7 +195,7 @@ TEST_CASE("Unit_hipMemcpyPeerAsync_Negative_Parameters") {
const hipStream_t stream = stream_guard.stream();
constexpr auto InvalidStream = [] {
StreamGuard sg(Streams::created);
const StreamGuard sg(Streams::created);
return sg.stream();
};
@@ -1,5 +1,6 @@
set(COMMON_SHARED_SRC vulkan_test.cc)
set(TEST_SRC
vulkan_test.cc
hipExternalMemoryGetMappedBuffer.cc
hipImportExternalMemory.cc
hipDestroyExternalMemory.cc
@@ -17,16 +18,19 @@ if(NOT Vulkan_FOUND)
message(STATUS "FOUND VULKAN SDK: $ENV{VULKAN_SDK}")
set(VULKAN_PATH $ENV{VULKAN_SDK})
else()
message("Error: Unable to locate Vulkan SDK. please specify VULKAN_PATH")
message(STATUS "Vulkan sdk not found, interop test not enabled. Please add VULKAN_PATH to enable the test")
return()
endif()
endif()
if(WIN32)
set(LINKER_LIBS vulkan-1)
else()
set(LINKER_LIBS vulkan)
endif()
hip_add_exe_to_target(NAME VulkanInteropTest
TEST_SRC ${TEST_SRC}
TEST_TARGET_NAME build_tests)
if (WIN32)
target_link_libraries(VulkanInteropTest vulkan-1)
else (WIN32)
target_link_libraries(VulkanInteropTest vulkan)
endif (WIN32)
TEST_TARGET_NAME build_tests
COMMON_SHARED_SRC ${COMMON_SHARED_SRC}
LINKER_LIBS ${LINKER_LIBS})